@@ -3,13 +3,15 @@ Main interface for rds-data service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.rds_data import RDSDataServiceClient
+    from mypy_boto3_rds_data import RDSDataServiceClient
 
     session = boto3.Session()
 
     client: RDSDataServiceClient = boto3.client("rds-data")
     session_client: RDSDataServiceClient = session.client("rds-data")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Any, Dict, List, TYPE_CHECKING, Type
@@ -41,7 +43,7 @@ class Exceptions:
 
 class RDSDataServiceClient:
     """
-    [RDSDataService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/rds-data.html#RDSDataService.Client)
+    [RDSDataService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/rds-data.html#RDSDataService.Client)
     """
 
     exceptions: Exceptions
@@ -57,26 +59,26 @@ class RDSDataServiceClient:
         transactionId: str = None,
     ) -> BatchExecuteStatementResponseTypeDef:
         """
-        [Client.batch_execute_statement documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/rds-data.html#RDSDataService.Client.batch_execute_statement)
+        [Client.batch_execute_statement documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/rds-data.html#RDSDataService.Client.batch_execute_statement)
         """
 
     def begin_transaction(
         self, resourceArn: str, secretArn: str, database: str = None, schema: str = None
     ) -> BeginTransactionResponseTypeDef:
         """
-        [Client.begin_transaction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/rds-data.html#RDSDataService.Client.begin_transaction)
+        [Client.begin_transaction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/rds-data.html#RDSDataService.Client.begin_transaction)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/rds-data.html#RDSDataService.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/rds-data.html#RDSDataService.Client.can_paginate)
         """
 
     def commit_transaction(
         self, resourceArn: str, secretArn: str, transactionId: str
     ) -> CommitTransactionResponseTypeDef:
         """
-        [Client.commit_transaction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/rds-data.html#RDSDataService.Client.commit_transaction)
+        [Client.commit_transaction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/rds-data.html#RDSDataService.Client.commit_transaction)
         """
 
     def execute_sql(
@@ -88,7 +90,7 @@ class RDSDataServiceClient:
         schema: str = None,
     ) -> ExecuteSqlResponseTypeDef:
         """
-        [Client.execute_sql documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/rds-data.html#RDSDataService.Client.execute_sql)
+        [Client.execute_sql documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/rds-data.html#RDSDataService.Client.execute_sql)
         """
 
     def execute_statement(
@@ -105,7 +107,7 @@ class RDSDataServiceClient:
         transactionId: str = None,
     ) -> ExecuteStatementResponseTypeDef:
         """
-        [Client.execute_statement documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/rds-data.html#RDSDataService.Client.execute_statement)
+        [Client.execute_statement documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/rds-data.html#RDSDataService.Client.execute_statement)
         """
 
     def generate_presigned_url(
@@ -116,12 +118,12 @@ class RDSDataServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/rds-data.html#RDSDataService.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/rds-data.html#RDSDataService.Client.generate_presigned_url)
         """
 
     def rollback_transaction(
         self, resourceArn: str, secretArn: str, transactionId: str
     ) -> RollbackTransactionResponseTypeDef:
         """
-        [Client.rollback_transaction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/rds-data.html#RDSDataService.Client.rollback_transaction)
+        [Client.rollback_transaction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/rds-data.html#RDSDataService.Client.rollback_transaction)
         """
